/*
 * Copyright (C) 2009 Splitted-Desktop Systems. All Rights Reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sub license, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 * 
 * The above copyright notice and this permission notice (including the
 * next paragraph) shall be included in all copies or substantial portions
 * of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT.
 * IN NO EVENT SHALL PRECISION INSIGHT AND/OR ITS SUPPLIERS BE LIABLE FOR
 * ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

#ifndef VA_GLX_H
#define VA_GLX_H

#ifdef IN_LIBVA
#include "va.h"
#else
#include <va/va.h>
#endif
#include <GL/glx.h>

/**
 * Returns a suitable VADisplay for VA API
 *
 * @param dpy the X11 display
 * @return VA_STATUS_SUCCESS if successful
 */
VADisplay vaGetDisplayGLX(
    Display *dpy
);

/**
 * Copy VA API surface to an OpenGL texture
 *
 * The application shall maintain the live GLX context itself.
 * Implementations are free to use glXGetCurrentContext() and
 * glXGetCurrentDrawable() functions for internal purposes.
 *
 * The default texture (0) will be bound on exit from this function.
 *
 * @param dpy the VA API display
 * @param surface the VA API surface
 * @param texture the OpenGL 2D texture
 * @param flags the PutSurface flags
 * @return VA_STATUS_SUCCESS if successful
 */
VAStatus vaCopySurfaceToTextureGLX(
    VADisplay    dpy,
    VASurfaceID  surface,
    GLuint       texture,
    unsigned int flags
);

/**
 * Bind VA API surface to an OpenGL texture
 *
 * The application shall maintain the live GLX context itself.
 * Implementations are free to use glXGetCurrentContext() and
 * glXGetCurrentDrawable() functions for internal purposes.
 *
 * @param dpy the VA API display
 * @param surface the VA API surface
 * @param texture the OpenGL 2D texture
 * @param flags the PutSurface flags
 * @return VA_STATUS_SUCCESS if successful
 */
VAStatus vaBindSurfaceToTextureGLX(
    VADisplay    dpy,
    VASurfaceID  surface,
    unsigned int texture,
    unsigned int flags
);

/**
 * Release VA API surface from an OpenGL texture
 *
 * The application shall maintain the live GLX context itself.
 * Implementations are free to use glXGetCurrentContext() and
 * glXGetCurrentDrawable() functions for internal purposes.
 *
 * The default texture (0) will be bound on exit from this function.
 *
 * @param dpy the VA API display
 * @param surface the VA API surface
 * @return VA_STATUS_SUCCESS if successful
 */
VAStatus vaReleaseSurfaceFromTextureGLX(
    VADisplay    dpy,
    VASurfaceID  surface
);

#endif /* VA_GLX_H */
